import os
from typing import Any, Callable, Optional


def to_boolean(value: str) -> bool:
    """Cast a string value to a boolean.

    This function will return `True` if the value specified falls
    within one of the supported truthy values, otherwise, `False`
    is returned.
    """
    return value.lower() in ("true", "yes", "1", "on")


def to_list(value: str, separator: str = ",") -> list:
    """Cast a string value to a list.

    This function will split the value using the specified separator
    value, the resulting list is returned.
    """
    return value.split(separator)


def getenv(
    name: str,
    default: Optional[Any] = None,
    cast: Optional[Callable] = None,
    required: bool = False,
) -> Any:
    """Attempt to retrieve an environment variable from the current system using
    the specified `name` argument.

    An optional `default` argument can be specified to fall back to a specific value
    when the specified environment variable is unavailable.

    An optional `cast` argument can be specified to attempt to cast the environment
    variable using a callable function.

    If the `required` argument is enabled, a `ValueError` will be raised when the
    specified environment variable is unavailable.
    """
    try:
        value = os.environ[name]
    except KeyError:
        if not required:
            return default
        else:
            raise ValueError(
                "Required environment variable '%s' could not be loaded, ensure "
                "your environment file includes all required environment variables."
                % name
            )
    else:
        return cast(value) if cast else value



from setuptools import find_packages, setup
import os

# Read the README file for long description
def read_readme():
    readme_path = os.path.join(os.path.dirname(__file__), "README.md")
    if os.path.exists(readme_path):
        with open(readme_path, "r", encoding="utf-8") as f:
            return f.read()
    return ""

setup(
    name="enventory",
    version="0.0.3",
    packages=find_packages(),
    python_requires=">=3.8",
    
    # Basic metadata
    description="A lightweight Python utility for loading and retrieving environment variables",
    long_description=read_readme(),
    long_description_content_type="text/markdown",
    
    # Author information
    author="Bec",
    author_email="",  # Add your email here
    
    # Project URLs
    url="https://github.com/becurrie/enventory",  # Update with actual GitHub URL
    project_urls={
        "Bug Reports": "https://github.com/becurrie/enventory/issues",
        "Source": "https://github.com/becurrie/enventory",
        "Documentation": "https://github.com/becurrie/enventory#readme",
    },
    
    # Dependencies
    install_requires=[],
    
    # Keywords for PyPI search
    keywords=[
        "environment", "env", "dotenv", "configuration", "settings", 
        "environment-variables", "config", "utilities"
    ],
    
    # Classifiers for PyPI categorization
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Systems Administration",
        "Topic :: Utilities",
    ],
    
    # Additional metadata
    license="MIT",
    zip_safe=False,
    include_package_data=True,
)
